@@ -1,6 +1,6 @@
 package PMLTQ::Commands;
 our $AUTHORITY = 'cpan:MICHALS';
-$PMLTQ::Commands::VERSION = '1.0.0';
+$PMLTQ::Commands::VERSION = '1.0.1';
 # ABSTRACT: PMLTQ command line interface
 
 use PMLTQ::Base -strict;
@@ -151,19 +151,6 @@ sub _load_config {
   return merge( $config, DEFAULT_CONFIG($base_dir) );
 }
 
-# sub verify_config {
-#   my $conf = shift;
-#   die "empty config file !!!" unless $conf;
-#   die "config not contain db !!!" unless ref($conf) && ref($conf) eq 'HASH'  &&  exists($conf->{db});
-#   for my $d (qw/name host port user password/) {
-#     die "config not contain db->$d !!!" unless  exists($conf->{db}->{$d});
-#   }
-#   for my $d (qw/data_dir layers/) {
-#     warn "config not contain $d !!!" unless  exists($conf->{$d});
-#   }
-#   die "layers sould be array !!!" unless exists($conf->{layers}) || ref($conf->{layers}) eq 'ARRAY';
-# }
-
 1;
 
 __END__
@@ -178,7 +165,208 @@ PMLTQ::Commands - PMLTQ command line interface
 
 =head1 VERSION
 
-version 1.0.0
+version 1.0.1
+
+=head1 SYNOPSIS
+
+  Usage: pmltq COMMAND [OPTIONS]
+
+    pmltq version
+    pmltq init schema1.xml schema2.xml
+    pmltq convert
+    pmltq load
+
+  Options (for all commands):
+    -c, --config      Config file, by default commands will look
+                      for config file called C<pmltq.yml> in the
+                      current directory.
+
+=head1 COMMANDS
+
+These commands are available by default.
+
+=head2 convert
+
+  $ pmltq convert
+
+Uses L<PMLTQ::Command::covert> to convert data in the C<data_dir> based on
+layers configuration
+
+=head2 delete
+
+  $ pmltq delete
+
+Uses L<PMLTQ::Command::delete> to delete the database for current treebank
+
+=head2 init
+
+  $ pmltq init resources/schema1.xml resources/schema2.xml
+
+Uses L<PMLTQ::Command::init> to generate initial configuration file skeleton
+based on given schemas. This command can help you quickly bootstrap the layers
+configuration
+
+=head2 initdb
+
+  $ pmltq initdb
+
+Uses L<PMLTQ::Command::initdb> to create and initialize new database for given
+treebank
+
+=head2 load
+
+  $ pmltq load
+
+Uses L<PMLTQ::Command::load> to load the data generated by C<convert> command
+
+=head2 query
+
+Uses L<PMLTQ::Command::query> to run a query on given treebank. B<Currently doesn't work>
+
+=head2 verify
+
+Uses L<PMLTQ::Command::verify> to check if database exists and contains some
+data. For now the checking is very simple
+
+=head2 version
+
+Uses L<PMLTQ::Command::version> to display current PMLTQ version
+
+=head1 CONFIG FILE
+
+=head2 Options
+
+=over 2
+
+=item C<treebank_id>
+
+ID of the treebank. Can contain only [a-zA-Z0-9_]. It will be default for the
+database name.
+
+=item C<data_dir>
+
+Directory where the data are (this is also base directory for data layers)
+
+Defaults: B<data>
+
+=item C<resources>
+
+Base directory for PML schemas
+
+Defaults: B<resources>
+
+=item C<output_dir>
+
+Directory for all sql dump files. The files generated by C<convert> and used by C<load> command
+
+Defaults: B<sql_dump>
+
+=item C<db>
+
+=over 4
+
+=item C<name>
+
+Database name
+
+Defaults: B<C<treebank_id>> if defined
+
+=item C<host>
+
+Database server hostname or IP address
+
+Defaults: B<localhost>
+
+=item C<port>
+
+Database port
+
+Defaults: B<5432>
+
+=item C<user>, C<password>
+
+Database credentials
+
+=back
+
+=item C<sys_db>
+
+Name of the 'system database' used for administration commands such as
+C<CREATE> and C<DROP>.
+
+=item C<layers>
+
+The configuration of treebank's layers and references for each layer.
+
+=over 4
+
+=item C<name>
+
+Schema root name
+
+=item C<data>
+
+A C<glob> path name matching pattern relative to C<data_dir>
+
+=item C<related-schema>
+
+List of related schemas that contain node types required in this layer's
+reference configuration
+
+=item C<references>
+
+This is key-value hash where key is path to the member of the node structure
+and value is node type or '-' (dash) if you intend to ignore that particular
+reference. If the node type is not in the current layer schema you have to
+prefix node type with the schema name and the appropriate schema have to be
+listed in C<related-schema> list.
+
+Examples:
+
+  references:
+    path/attr1: '-' #--> ignore this reference
+    path/attr2: ref-node #--> reference node type 'ref-node'
+    path/attr3: schema:other-node #--> reference node type 'other-node' in schema 'schema'
+
+=back
+
+=back
+
+=head2 Change values using CLI
+
+You can use command line parameters to modify any configuration options.
+
+For example you can use
+
+  pmltq load --output_dir='/some/path' --data_dir='some/other/path' --db-name='abc'
+
+Dash C<-> in the parameter's name means dive into the hash, so C<--db-name='abc'> is
+going to change C<db: name: 'abc'> while C<--db_name='abc'> would just set configuration
+option C<db_name: 'abc'>.
+
+=head2 Example:
+
+  data_dir: /pmltq/data/dir/ # directory where the data are (this is also base directory for data layers)
+  resources: /pmltq/resources/ # main directory with PML schemas
+
+  db: # typical DB auth stuff
+    name: treebank_db_name
+    host: localhost
+    port: 5432
+    user: pmltq
+    password: pwd
+
+  layers: # description of all data layers
+    - name: adata
+      data: ./relative/to/data_dir/**/*.a.gz
+      related-schema:
+        - adata_schema.xml
+      references:
+        t-node/val_frame.rf: '-'
+        t-a/aux.rf: 'adata:a-node'
+        t-node/coref_gram.rf: t-node
+    - name: tdata
+      data: **/*.t.gz
 
 =head1 AUTHORS
 
